[−][src]Macro toml_query::warn
This macro is defined if the logging feature is not compiled into the library
It ignores all logging calls inside the library.
This macro is defined if the logging feature is not compiled into the library
It ignores all logging calls inside the library.